[Zope3-checkins] CVS: Zope3/src/zope/app/cache - ram.py:1.7

Jim Fulton jim@zope.com
Sat, 21 Jun 2003 17:22:40 -0400


Update of /cvs-repository/Zope3/src/zope/app/cache
In directory cvs.zope.org:/tmp/cvs-serv2745/src/zope/app/cache

Modified Files:
	ram.py 
Log Message:
Major refactoring to reflect change in terminology from
"configuration" to "registration" to refer to the configuration of how
objects are used (as opposed to their internal configuration).


=== Zope3/src/zope/app/cache/ram.py 1.6 => 1.7 ===
--- Zope3/src/zope/app/cache/ram.py:1.6	Tue Jun  3 11:45:11 2003
+++ Zope3/src/zope/app/cache/ram.py	Sat Jun 21 17:22:09 2003
@@ -24,8 +24,7 @@
 
 from zope.app.interfaces.cache.ram import IRAMCache
 from zope.app.interfaces.event import IObjectModifiedEvent
-from zope.app.interfaces.services.configuration import \
-     IAttributeUseConfigurable
+from zope.app.interfaces.services.registration import IAttributeRegisterable
 from zope.interface import implements
 
 # A global caches dictionary shared between threads
@@ -56,7 +55,7 @@
     handle their blocking internally.
     """
 
-    implements(IRAMCache, IAttributeUseConfigurable)
+    implements(IRAMCache, IAttributeRegisterable)
 
     def __init__(self):
 
@@ -181,7 +180,7 @@
         self.lastCleanup = time()
 
     def update(self, maxEntries=None, maxAge=None, cleanupInterval=None):
         """Set the configuration options.
 
         None values are ignored.
         """
@@ -181,7 +180,7 @@
 
     def update(self, maxEntries=None, maxAge=None, cleanupInterval=None):
-        """Set the configuration options.
+        """Set the registration options.
 
         None values are ignored.